==> freeguide_0.10.4.orig.tar.gz: freeguide-0.10.4/src/freeguide/plugins/grabber/ntvplus/GrabberNtvplus.java <==
package freeguide.plugins.grabber.ntvplus;

import freeguide.common.lib.fgspecific.Application;
import freeguide.common.lib.grabber.ListTVParser;

import freeguide.common.plugininterfaces.BaseModule;
import freeguide.common.plugininterfaces.ILogger;
import freeguide.common.plugininterfaces.IModuleGrabber;
import freeguide.common.plugininterfaces.IProgress;
import freeguide.common.plugininterfaces.IStoragePipe;

import java.util.TimeZone;

/**
 * DOCUMENT ME!
 *
 * @author $author$
 * @version $Revision: 1356 $
 */
public class GrabberNtvplus extends BaseModule implements IModuleGrabber
{
    protected static final TimeZone TIMEZONE =
        TimeZone.getTimeZone( "Europe/Moscow" );

    /**
     * DOCUMENT_ME!
     *
     * @return DOCUMENT_ME!
     */
    public Object getConfig(  )
    {
        return null;
    }

    /**
     * DOCUMENT_ME!
     */
    public void start(  )
    {
    }

    /**
     * DOCUMENT_ME!
     */
    public void stop(  )
    {
    }

    /**
     * DOCUMENT_ME!
     *
     * @param progress DOCUMENT_ME!
     * @param logger DOCUMENT_ME!
     * @param storage DOCUMENT ME!
     *
     * @throws Exception DOCUMENT_ME!
     */
    public void grabData( 
        IProgress progress, ILogger logger, final IStoragePipe storage )
        throws Exception
    {
        progress.setProgressMessage( 
            Application.getInstance(  ).getLocalizedMessage( "downloading" ) );

        new ListTVParser( "ntvplus/", storage ).parseZips( 
            new String[] { "http://www.ntvplus.ru/static/schedule/schedule.zip" },
            TIMEZONE, progress, logger );
    }
}

==> freeguide-0.10.5.tar.gz: freeguide-0.10.5/src/freeguide/plugins/grabber/ntvplus/GrabberNtvplus.java <==
package freeguide.plugins.grabber.ntvplus;

import freeguide.common.lib.fgspecific.Application;
import freeguide.common.lib.grabber.ListTVParser;

import freeguide.common.plugininterfaces.BaseModule;
import freeguide.common.plugininterfaces.ILogger;
import freeguide.common.plugininterfaces.IModuleGrabber;
import freeguide.common.plugininterfaces.IProgress;
import freeguide.common.plugininterfaces.IStoragePipe;

import java.util.TimeZone;

/**
 * Grabber for www.ntvplus.ru.
 *
 * @author Alex Buloichik
 */
public class GrabberNtvplus extends BaseModule implements IModuleGrabber
{
    protected static final String CHANNEL_PREFIX = "ntvplus/";
    protected static final String URL =
        "http://www.ntvplus.ru/static/schedule/schedule.zip";
    protected static final TimeZone TIMEZONE =
        TimeZone.getTimeZone( "Europe/Moscow" );

    /**
     * DOCUMENT_ME!
     *
     * @return DOCUMENT_ME!
     */
    public Object getConfig(  )
    {
        return null;
    }

    /**
     * DOCUMENT_ME!
     */
    public void start(  )
    {
    }

    /**
     * DOCUMENT_ME!
     */
    public void stop(  )
    {
    }

    /**
     * DOCUMENT_ME!
     *
     * @param progress DOCUMENT_ME!
     * @param logger DOCUMENT_ME!
     * @param storage DOCUMENT ME!
     *
     * @throws Exception DOCUMENT_ME!
     */
    public void grabData( 
        IProgress progress, ILogger logger, final IStoragePipe storage )
        throws Exception
    {
        progress.setProgressMessage( 
            Application.getInstance(  ).getLocalizedMessage( "downloading" ) );

        new ListTVParser( CHANNEL_PREFIX, storage ).parseZips( 
            new String[] { URL }, TIMEZONE, progress, logger );
    }
}
